pub struct FixedVsFloatingSwapResults {
pub swap: SwapResults,
pub fair_rate: Option<Rate>,
pub fair_spread: Option<Spread>,
}Expand description
Results returned by a fixed-vs-floating swap engine (the C++
FixedVsFloatingSwap::results, which derives from Swap::results).
Fields
swap: SwapResultsThe swap-level results (leg NPVs, BPS and discounts).
fair_rate: Option<Rate>The fair fixed rate that zeroes the swap NPV.
fair_spread: Option<Spread>The fair spread over the floating index that zeroes the swap NPV.