FilonIntegral

Struct FilonIntegral 

pub struct FilonIntegral { /* private fields */ }
Filon integrator for f(x) * {sin,cos}(t x) over an even interval count.

Implementations

Source

impl FilonIntegral

pub fn new(kind: FilonType, t: Real, intervals: Size) -> QlResult<Self>

A Filon integrator against sin/cos of frequency t, splitting the domain into intervals equal sub-intervals.

Errors

Returns an error unless intervals is even and positive, and t is finite and non-zero (Filon’s coefficients divide by t * h).